@@ -6,7 +6,8 @@ class meta_data:
     this class contains all the data necessary to run the workers
     """
     def __init__(self,obj):
-        self.workers = obj.workers    ###dictionary oh ost and walker workers
+        self.workers = obj.workers    ###dictionary of host and walker workers
+        self.x0 = obj.x0
         self.func = obj.func
         self.grad = obj.grad
         self.hess = obj.hess
